@@ -1,12 +1,13 @@
 package Text::TOC::OutputHandler::HTML;
 BEGIN {
-  $Text::TOC::OutputHandler::HTML::VERSION = '0.05';
+  $Text::TOC::OutputHandler::HTML::VERSION = '0.06';
 }
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+use List::AllUtils qw( max );
 use Text::TOC::Types qw( CodeRef Str );
 
 use Moose;
@@ -48,15 +49,20 @@ sub process_node_list {
     my $list = $toc->createElement($list_tag);
     $toc->appendChild($list);
 
+    my $max_level = max map { $self->_node_level($_) } @{$nodes};
+
     my @lists = $list;
 
-    my $level = 1;
     my $last_node;
 
     for my $node ( @{$nodes} ) {
         $self->_insert_anchor($node);
 
-        my $diff = $self->_node_level_difference( $node, $last_node );
+        my $diff
+            = $last_node
+            ? $self->_node_level_difference( $node, $last_node )
+            : $max_level - $self->_node_level($node);
+
         if ( $diff > 0 ) {
             for ( 1..$diff ) {
                 my $new_list = $toc->createElement($list_tag);
@@ -149,7 +155,7 @@ Text::TOC::OutputHandler::HTML - Implements an output handler for HTML documents
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 DESCRIPTION
 
